@@ -4,13 +4,13 @@
 module ServerSpec (spec) where
 
 import Control.Concurrent
+import qualified Control.Exception as E
 import Data.ByteString.Builder (byteString)
 import Network.HTTP.Types
 import Network.Run.TCP
 import System.Exit
 import System.Process.Typed
 import Test.Hspec
-import qualified UnliftIO.Exception as E
 
 import Network.HTTP2.Server
 
@@ -34,7 +34,7 @@ runServer = runTCPServer (Just host) port runHTTP2Server
         E.bracket
             (allocSimpleConfig s 4096)
             freeSimpleConfig
-            (`run` server)
+            (\conf -> run defaultServerConfig conf server)
 
 server :: Server
 server req _aux sendResponse = case requestMethod req of
